OC.L10N.register(
    "files_external",
    {
    "External storage" : "พื้นที่จัดเก็บข้อมูลภายนอก",
    "Personal" : "ส่วนตัว",
    "System" : "ระบบ",
    "Grant access" : "อนุญาตให้เข้าถึง",
    "Error configuring OAuth1" : "ข้อผิดพลาดในการกำหนดค่า OAuth1",
    "Please provide a valid app key and secret." : "โปรดระบุคีย์และรหัสลับของแอปให้ถูกต้อง",
    "Error configuring OAuth2" : "ข้อผิดพลาดในการกำหนดค่า OAuth2",
    "Generate keys" : "สร้างคีย์",
    "Error generating key pair" : "ข้อผิดพลาดในการสร้างคู่ของคีย์",
    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
    "Enable previews" : "เปิดใช้งานการแสดงตัวอย่าง",
    "Enable sharing" : "เปิดให้สามารถแชร์ได้",
    "Check for changes" : "ตรวจสอบการเปลี่ยนแปลง",
    "Never" : "ไม่เคย",
    "Once every direct access" : "ทุก ๆ การเข้าถึงโดยตรง",
    "Admin defined" : "กำหนดโดยผู้ดูแลระบบ",
    "Saved" : "บันทึกแล้ว",
    "Saving …" : "กำลังบันทึก …",
    "Save" : "บันทึก",
    "Empty response from the server" : "การตอบสนองจากเซิร์ฟเวอร์ว่างเปล่า",
    "Couldn't get the list of external mount points: {type}" : "ไม่สามารถรับรายชื่อของจุดเชื่อมต่อภายนอก: {type}",
    "There was an error with message: " : "มีข้อผิดพลาดพร้อมข้อความ:",
    "External mount error" : "ข้อผิดพลาดจุดเชื่อมต่อภายนอก",
    "external-storage" : "external-storage",
    "Please enter the credentials for the {mount} mount" : "กรุณากรอกข้อมูลประจำตัวสำหรับจุดเชื่อมต่อ {mount} ",
    "Username" : "ชื่อผู้ใช้",
    "Password" : "รหัสผ่าน",
    "Credentials saved" : "บันทึกข้อมูลประจำตัวแล้ว",
    "Credentials saving failed" : "บันทึกข้อมูลประจำตัวล้มเหลว",
    "Credentials required" : "จำเป็นต้องระบุข้อมูลประจำตัว",
    "Invalid backend or authentication mechanism class" : "แบ็กเอนด์หรือกลไกการรับรองความถูกต้องไม่ถูกต้อง",
    "Invalid mount point" : "จุดเชื่อมต่อไม่ถูกต้อง",
    "Objectstore forbidden" : "ที่เก็บวัตถุไม่ได้รับอนุญาต",
    "Invalid storage backend \"%s\"" : "แบ็กเอนด์การจัดเก็บข้อมูล \"%s\" ไม่ถูกต้อง",
    "Not permitted to use backend \"%s\"" : "ไม่อนุญาตให้ใช้แบ็กเอนด์ \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "ไม่อนุญาตให้ใช้กลไกตรวจสอบการรับรองความถูกต้อง \"%s\"",
    "Unsatisfied backend parameters" : "พารามิเตอร์แบ็กเอนด์ไม่เพียงพอ",
    "Unsatisfied authentication mechanism parameters" : "พารามิเตอร์การรับรองความถูกต้องไม่เพียงพอ",
    "Insufficient data: %s" : "ข้อมูลไม่เพียงพอ: %s",
    "%s" : "%s",
    "Access key" : "คีย์การเข้าถึง",
    "Secret key" : "คีย์ลับ",
    "Builtin" : "ในตัว",
    "None" : "ไม่มี",
    "OAuth1" : "OAuth1",
    "App key" : "คีย์แอป",
    "App secret" : "ข้อมูลลับแอป",
    "OAuth2" : "OAuth2",
    "Client ID" : "รหัสไคลเอ็นต์",
    "Client secret" : "ข้อมูลลับไคลเอ็นต์",
    "Tenant name" : "ชื่อผู้เช่า",
    "Identity endpoint URL" : "ตัวตนของ URL ปลายทาง",
    "Domain" : "โดเมน",
    "Rackspace" : "Rackspace",
    "API key" : "รหัส API",
    "Log-in credentials, save in database" : "ข้อมูลประจำตัวสำหรับเข้าสู่ระบบ บันทึกในฐานข้อมูล",
    "Username and password" : "ชื่อผู้ใช้และรหัสผ่าน",
    "Log-in credentials, save in session" : "ข้อมูลประจำตัวสำหรับเข้าสู่ระบบ, บันทึกในเซสชัน",
    "User entered, store in database" : "ใส่โดยผู้ใช้ จัดเก็บในฐานข้อมูล",
    "RSA public key" : "คีย์สาธารณะ RSA",
    "Public key" : "คีย์สาธารณะ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "ชื่อโฮสต์",
    "Port" : "พอร์ต",
    "Region" : "พื้นที่",
    "Enable SSL" : "เปิดใช้งาน SSL",
    "Enable Path Style" : "เปิดใช้งานสไตล์เส้นทาง",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "โฟลเดอร์ย่อยรีโมท",
    "Secure https://" : "โหมดปลอดภัย https://",
    "FTP" : "FTP",
    "Host" : "โฮสต์",
    "Secure ftps://" : "โหมดปลอดภัย ftps://",
    "Local" : "ต้นทาง",
    "Location" : "ตำแหน่ง",
    "SFTP" : "SFTP",
    "Root" : "รูท",
    "SFTP with secret key login" : "SFTP เข้าสู่ระบบด้วยคีย์ลับ",
    "Share" : "แชร์",
    "Show hidden files" : "แสดงไฟล์ที่ซ่อนอยู่",
    "Username as share" : "ชื่อผู้ใช้ที่แชร์",
    "OpenStack Object Storage" : "ที่เก็บวัตถุ OpenStack",
    "Service name" : "ชื่อบริการ",
    "Request timeout (seconds)" : "หมดเวลาคำขอ (วินาที)",
    "Name" : "ชื่อ",
    "Storage type" : "ชนิดการจัดเก็บข้อมูล",
    "Scope" : "ขอบเขต",
    "Open documentation" : "เปิดเอกสารประกอบ",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Authentication" : "การรับรองความถูกต้อง",
    "Configuration" : "การกำหนดค่า",
    "Available for" : "ใช้ได้สำหรับ",
    "Add storage" : "เพิ่มพื้นที่จัดเก็บข้อมูล",
    "Advanced settings" : "การตั้งค่าขั้นสูง",
    "Allow users to mount external storage" : "อนุญาตให้ผู้ใช้ติดตั้งการจัดเก็บข้อมูลภายนอก",
    "All users. Type to select user or group." : "ผู้ใช้ทุกคน พิมพ์เพื่อเลือกผู้ใช้หรือกลุ่ม"
},
"nplurals=1; plural=0;");
